@@ -10,7 +10,7 @@ class BidSchema(CamelCaseSchema):
   id = fields.UUID()
   quote_id = fields.UUID()
   carrier_id = fields.UUID()
-  receipt_id = fields.String()
+  receipt_id = fields.String(allow_none=True)
   amount = fields.Integer()
   estimated_days = fields.Integer()
   notes = fields.String(allow_none=True)
