@@ -85,6 +85,9 @@ class TransactionSchema(CamelCaseSchema):
 	provider = fields.String(allow_none=True)
 	target_pay = fields.Integer(allow_none=True)
 	max_buy = fields.Integer(allow_none=True)
+	pieces = fields.Integer(allow_none=True)
+	max_temperature = fields.Float(allow_none=True)
+	min_temperature = fields.Float(allow_none=True)
 
 	@post_load
 	def classify(self, data, **kwargs):
